@@ -3,6 +3,8 @@ from cv2 import face
 import matplotlib.pyplot as plt
 import numpy as np
 
+import blurredface_sts_test
+
 #打码函数
 # size为打码的方块大小
 def drawMask(x_start,x_end,y_start,y_end,size,img):
@@ -26,24 +28,29 @@ def faceRecognizer(filepath):
     # cv2.namedWindow('recognizer')
     # OpenCV人脸识别分类器
     classifier_default = cv2.CascadeClassifier(
-        #"haarcascades/haarcascade_frontalface_default.xml"
-        "haarcascade_frontalface_default.xml"
+        # "haarcascades/haarcascade_frontalface_default.xml"
+        # "haarcascade_frontalface_default.xml"
+        blurredface_sts_test.haarcascade.haarcascade_frontalface_default
     )
     classifier_alt_tree = cv2.CascadeClassifier(
         # "haarcascades/haarcascade_frontalface_alt_tree.xml"
-        "haarcascade_frontalface_alt_tree.xml"
+        # "haarcascade_frontalface_alt_tree.xml"
+        blurredface_sts_test.haarcascade.haarcascade_frontalface_alt_tree
     )
     classifier_alt2 = cv2.CascadeClassifier(
-        #"haarcascades/haarcascade_frontalface_alt2.xml"
-        "haarcascade_frontalface_alt2.xml"
+        # "haarcascades/haarcascade_frontalface_alt2.xml"
+        # "haarcascade_frontalface_alt2.xml"
+        blurredface_sts_test.haarcascade.haarcascade_frontalface_alt2
     )
     classifier_alt = cv2.CascadeClassifier(
-        #"haarcascades/haarcascade_frontalface_alt.xml"
-        "haarcascade_frontalface_alt.xml"
+        # "haarcascades/haarcascade_frontalface_alt.xml"
+        # "haarcascade_frontalface_alt.xml"
+        blurredface_sts_test.haarcascade.haarcascade_frontalface_alt
     )
     classifier_ce = cv2.CascadeClassifier(
-        #"haarcascades/haarcascade_profileface.xml"
-        "haarcascade_profileface.xml"
+        # "haarcascades/haarcascade_profileface.xml"
+        # "haarcascade_profileface.xml"
+        blurredface_sts_test.haarcascade.haarcascade_profileface
     )
     color = (0, 0, 255)  # 定义绘制颜色
     # 调用识别人脸
